# Installing

You can install pop-tools with `pip`, `conda`, or by installing from source.

## Pip

Pip can be used to install pop-tools:

```bash
python -m pip install pop-tools
```

## Conda

To install the latest version of pop-tools from the [conda-forge](https://conda-forge.github.io) channel using
[conda](https://www.anaconda.com/downloads):

```bash
conda install -c conda-forge pop-tools
```

## Install from Source

To install pop-tools from source, clone the repository from [Github](https://github.com/NCAR/pop-tools)

```bash
git clone https://github.com/NCAR/pop-tools.git
cd pop-tools
python -m pip install -e .
```

You can also install directly from git master branch::

```bash
python -m pip install git+https://github.com/NCAR/pop-tools
```
